@@ -73,9 +73,13 @@ class RemoteSession:
                           data=data,
                           headers={"x-access-token": KodexaPlatform.get_access_token()}, files=files)
         try:
-            execution = Dict(json.loads(r.text))
+            if r.status_code==200:
+                execution = Dict(json.loads(r.text))
+            else:
+                logger.error("Execution creation failed [" + r.text + "], response " + str(r.status_code))
+                raise Exception("Execution creation failed [" + r.text + "], response " + str(r.status_code))
         except JSONDecodeError:
-            logger.error("Unable to handle response [" + r.text + "]")
+            logger.error("Unable to handle response [" + r.text + "], response "+str(r.status_code))
             raise
 
         return execution
@@ -189,13 +193,12 @@ class RemotePipeline:
 
         for document in self.connector:
             logging.info(f"Processing {document}")
-            context = PipelineContext()
             execution = cloud_session.execution_action(document, self.parameters, self.attach_source)
             execution = cloud_session.wait_for_execution(execution)
 
             result_document = cloud_session.get_output_document(execution)
-            context.set_output_document(result_document)
-            cloud_session.merge_stores(execution, context)
+            self.context.set_output_document(result_document)
+            cloud_session.merge_stores(execution, self.context)
 
             self.context.statistics.processed_document(document)
             self.context.output_document = document
@@ -288,9 +291,11 @@ class RemoteAction:
         self.options = options
         self.auth = auth
 
-    def to_yaml(self):
-        # TODO needs implementation
-        config = {}
+    def to_dict(self):
+        return {
+            'ref': self.slug,
+            'options': self.options
+        }
 
     def get_name(self):
         return f"Remote Action ({self.slug})"
