@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import inspect
 import logging
 import sys
 import traceback
@@ -8,14 +9,15 @@ from collections import KeysView
 from enum import Enum
 from inspect import signature
 from io import StringIO
+from textwrap import dedent
 from typing import List, Optional, Dict
 from uuid import uuid4
 
 import yaml
 
 from kodexa.connectors import FolderConnector
-from kodexa.connectors.connectors import get_caller_dir
-from kodexa.model import Document
+from kodexa.connectors.connectors import get_caller_dir, KodexaPlatformStore
+from kodexa.model import Document, Store
 
 
 def new_id():
@@ -61,7 +63,7 @@ class InMemoryStoreProvider:
     def __init__(self):
         self.stores = {}
 
-    def put_store(self, name: str, store):
+    def put_store(self, name: str, store: Store):
         self.stores[name] = store
 
     def get_store(self, name):
@@ -79,9 +81,13 @@ class PipelineContext:
     It also provides access to the 'stores' that have been added to the pipeline
     """
 
-    def __init__(self, content_provider=InMemoryContentProvider(), store_provider=InMemoryStoreProvider(),
+    def __init__(self, content_provider=None, store_provider=None,
                  existing_content_objects=None,
                  context=None):
+        if content_provider is None:
+            content_provider = InMemoryContentProvider()
+        if store_provider is None:
+            store_provider = InMemoryStoreProvider()
         if context is None:
             context = {}
         if existing_content_objects is None:
@@ -150,7 +156,7 @@ class PipelineContext:
         """
         self.output_document = output_document
 
-    def get_store(self, name: str, default=None):
+    def get_store(self, name: str, default: Store = None) -> Store:
         """
         Get a store with given name from the context
 
@@ -189,9 +195,26 @@ class PipelineStep:
 
         if callable(self.step):
             logging.info(f"Adding new step function {step.__name__} to pipeline {self.name}")
+            self.name = step.__name__
         else:
             logging.info(f"Adding new step {step.get_name()} to pipeline {self.name}")
 
+    def to_dict(self):
+        try:
+            if callable(self.step):
+                metadata = {
+                    'function': self.step.__name__,
+                    'script': dedent(inspect.getsource(self.step))
+                }
+            else:
+                metadata = self.step.to_dict()
+            metadata['name'] = self.name
+            metadata['condition'] = self.condition
+            metadata['enabled'] = self.enabled
+            return metadata
+        except AttributeError as e:
+            raise Exception("All steps must implement to_dict() for deployment", e)
+
     def execute(self, context, document):
         if self.will_execute(context, document):
             try:
@@ -250,6 +273,7 @@ class Pipeline:
     :param stop_on_exception: Should the pipeline raise exceptions and stop (default True)
     :param logging_level: The logging level of the pipeline (default INFO)
     """
+    context: PipelineContext
 
     def __init__(self, connector, name="Default", stop_on_exception=True, logging_level=logging.INFO):
         logging.info(f"Initializing a new pipeline {name}")
@@ -332,7 +356,7 @@ class Pipeline:
         for step in self.steps:
 
             try:
-                configuration_steps.append(step.to_configuration())
+                configuration_steps.append(step.to_dict())
             except:
                 pass
 
@@ -429,6 +453,19 @@ class Pipeline:
         """
         return Pipeline(FolderConnector(folder_path, filename_filter, recursive, relative, caller_path))
 
+    @staticmethod
+    def from_store(org_slug: str, slug: str, query: str = "*") -> Pipeline:
+        """
+        Create a pipeline that will again the documents in a Kodexa platform store
+
+        :param org_slug: The organization's slug
+        :param slug: The store slug
+        :param query: A query to be applied (defaults to *)
+        :return: A new pipeline
+        :rtype: Pipeline
+        """
+        return Pipeline(KodexaPlatformStore(org_slug, slug, query))
+
 
 class PipelineStatistics:
     """
